==> jc-1.4.0.tar.gz: java/nio/charset/IllegalCharsetNameException.h <==
// public class java.nio.charset.IllegalCharsetNameException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 680cf34d05feb5a1 java_lang_IllegalArgumentException
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 37d3361033e3a73b java_nio_charset_IllegalCharsetNameException

// header file dependencies
// @dep_header java_lang_IllegalArgumentException

#include "java/lang/IllegalArgumentException.h"

#ifndef _JC_java_nio_charset_IllegalCharsetNameException_H_
#define _JC_java_nio_charset_IllegalCharsetNameException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_nio_charset_IllegalCharsetNameException$sub_refs	_jc_java_nio_charset_IllegalCharsetNameException$sub_refs;
typedef struct _jc_java_nio_charset_IllegalCharsetNameException$sub_nonrefs	_jc_java_nio_charset_IllegalCharsetNameException$sub_nonrefs;
typedef struct _jc_java_nio_charset_IllegalCharsetNameException$refs	_jc_java_nio_charset_IllegalCharsetNameException$refs;
typedef struct _jc_java_nio_charset_IllegalCharsetNameException$nonrefs	_jc_java_nio_charset_IllegalCharsetNameException$nonrefs;
typedef struct _jc_java_nio_charset_IllegalCharsetNameException$object	_jc_java_nio_charset_IllegalCharsetNameException$object;

typedef struct _jc_java_nio_charset_IllegalCharsetNameException$fields_struct	_jc_java_nio_charset_IllegalCharsetNameException$fields_struct;
typedef const struct _jc_java_nio_charset_IllegalCharsetNameException$vmethods	_jc_java_nio_charset_IllegalCharsetNameException$vmethods;
typedef const struct _jc_java_nio_charset_IllegalCharsetNameException$vtable	_jc_java_nio_charset_IllegalCharsetNameException$vtable;
typedef const struct _jc_java_nio_charset_IllegalCharsetNameException$vtype	_jc_java_nio_charset_IllegalCharsetNameException$vtype;

// Class fields structure
struct _jc_java_nio_charset_IllegalCharsetNameException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_nio_charset_IllegalCharsetNameException$fields_struct _jc_java_nio_charset_IllegalCharsetNameException$class_fields;

// Constructors
extern void _jc_java_nio_charset_IllegalCharsetNameException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_nio_charset_IllegalCharsetNameException$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_nio_charset_IllegalCharsetNameException$method$getCharsetName$975cbe5b5490a104(_jc_env *, struct _jc_java_nio_charset_IllegalCharsetNameException$object *);

// Virtual method descriptors
extern _jc_method _jc_java_nio_charset_IllegalCharsetNameException$method_info$getCharsetName$975cbe5b5490a104;

// Virtual methods structure
struct _jc_java_nio_charset_IllegalCharsetNameException$vmethods {
	struct _jc_java_lang_String$object	*(*getCharsetName$975cbe5b5490a104)(_jc_env *, struct _jc_java_nio_charset_IllegalCharsetNameException$object *);
};

// Vtable
struct _jc_java_nio_charset_IllegalCharsetNameException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_lang_IllegalArgumentException$vmethods	java_lang_IllegalArgumentException;
	_jc_java_nio_charset_IllegalCharsetNameException$vmethods	java_nio_charset_IllegalCharsetNameException;
};

// Vtype
struct _jc_java_nio_charset_IllegalCharsetNameException$vtype {
	_jc_type			type;
	_jc_java_nio_charset_IllegalCharsetNameException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_charset_IllegalCharsetNameException$sub_refs {
	struct _jc_java_lang_String$object	*charsetName;
};

// Reference instance fields (object)
struct _jc_java_nio_charset_IllegalCharsetNameException$refs {
    _jc_java_nio_charset_IllegalCharsetNameException$sub_refs	java_nio_charset_IllegalCharsetNameException;
    _jc_java_lang_IllegalArgumentException$sub_refs	java_lang_IllegalArgumentException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_charset_IllegalCharsetNameException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_charset_IllegalCharsetNameException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_lang_IllegalArgumentException$sub_nonrefs	java_lang_IllegalArgumentException;
    _jc_java_nio_charset_IllegalCharsetNameException$sub_nonrefs	java_nio_charset_IllegalCharsetNameException;
};

// Object instance structure
struct _jc_java_nio_charset_IllegalCharsetNameException$object {
	_jc_java_nio_charset_IllegalCharsetNameException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_charset_IllegalCharsetNameException$vtype	*vtype;
	_jc_java_nio_charset_IllegalCharsetNameException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_charset_IllegalCharsetNameException$vtype _jc_java_nio_charset_IllegalCharsetNameException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_charset_IllegalCharsetNameException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_charset_IllegalCharsetNameException$class_object;

#endif	/* _JC_java_nio_charset_IllegalCharsetNameException_H_ */

==> jc-1.4.6.tar.gz: java/nio/charset/IllegalCharsetNameException.h <==
// public class java.nio.charset.IllegalCharsetNameException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 680cf34d05feb5a1 java_lang_IllegalArgumentException
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 37d3361033e3a73b java_nio_charset_IllegalCharsetNameException

// header file dependencies
// @dep_header java_lang_IllegalArgumentException

#include "java/lang/IllegalArgumentException.h"

#ifndef _JC_java_nio_charset_IllegalCharsetNameException_H_
#define _JC_java_nio_charset_IllegalCharsetNameException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_nio_charset_IllegalCharsetNameException$sub_refs	_jc_java_nio_charset_IllegalCharsetNameException$sub_refs;
typedef struct _jc_java_nio_charset_IllegalCharsetNameException$sub_nonrefs	_jc_java_nio_charset_IllegalCharsetNameException$sub_nonrefs;
typedef struct _jc_java_nio_charset_IllegalCharsetNameException$refs	_jc_java_nio_charset_IllegalCharsetNameException$refs;
typedef struct _jc_java_nio_charset_IllegalCharsetNameException$nonrefs	_jc_java_nio_charset_IllegalCharsetNameException$nonrefs;
typedef struct _jc_java_nio_charset_IllegalCharsetNameException$object	_jc_java_nio_charset_IllegalCharsetNameException$object;

typedef struct _jc_java_nio_charset_IllegalCharsetNameException$fields_struct	_jc_java_nio_charset_IllegalCharsetNameException$fields_struct;
typedef const struct _jc_java_nio_charset_IllegalCharsetNameException$vmethods	_jc_java_nio_charset_IllegalCharsetNameException$vmethods;
typedef const struct _jc_java_nio_charset_IllegalCharsetNameException$vtable	_jc_java_nio_charset_IllegalCharsetNameException$vtable;
typedef const struct _jc_java_nio_charset_IllegalCharsetNameException$vtype	_jc_java_nio_charset_IllegalCharsetNameException$vtype;

// Class fields structure
struct _jc_java_nio_charset_IllegalCharsetNameException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_nio_charset_IllegalCharsetNameException$fields_struct _jc_java_nio_charset_IllegalCharsetNameException$class_fields;

// Constructors
extern void _jc_java_nio_charset_IllegalCharsetNameException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_nio_charset_IllegalCharsetNameException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_nio_charset_IllegalCharsetNameException$method$getCharsetName$975cbe5b5490a104(_jc_env *, struct _jc_java_nio_charset_IllegalCharsetNameException$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_nio_charset_IllegalCharsetNameException$method_info$getCharsetName$975cbe5b5490a104;

// Virtual methods structure
struct _jc_java_nio_charset_IllegalCharsetNameException$vmethods {
	struct _jc_java_lang_String$object	*(*getCharsetName$975cbe5b5490a104)(_jc_env *, struct _jc_java_nio_charset_IllegalCharsetNameException$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_nio_charset_IllegalCharsetNameException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_lang_IllegalArgumentException$vmethods	java_lang_IllegalArgumentException;
	_jc_java_nio_charset_IllegalCharsetNameException$vmethods	java_nio_charset_IllegalCharsetNameException;
};

// Vtype
struct _jc_java_nio_charset_IllegalCharsetNameException$vtype {
	_jc_type			type;
	_jc_java_nio_charset_IllegalCharsetNameException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_charset_IllegalCharsetNameException$sub_refs {
	struct _jc_java_lang_String$object	*charsetName;
};

// Reference instance fields (object)
struct _jc_java_nio_charset_IllegalCharsetNameException$refs {
    _jc_java_nio_charset_IllegalCharsetNameException$sub_refs	java_nio_charset_IllegalCharsetNameException;
    _jc_java_lang_IllegalArgumentException$sub_refs	java_lang_IllegalArgumentException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_charset_IllegalCharsetNameException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_charset_IllegalCharsetNameException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_lang_IllegalArgumentException$sub_nonrefs	java_lang_IllegalArgumentException;
    _jc_java_nio_charset_IllegalCharsetNameException$sub_nonrefs	java_nio_charset_IllegalCharsetNameException;
};

// Object instance structure
struct _jc_java_nio_charset_IllegalCharsetNameException$object {
	_jc_java_nio_charset_IllegalCharsetNameException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_charset_IllegalCharsetNameException$vtype	*vtype;
	_jc_java_nio_charset_IllegalCharsetNameException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_charset_IllegalCharsetNameException$vtype _jc_java_nio_charset_IllegalCharsetNameException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_charset_IllegalCharsetNameException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_charset_IllegalCharsetNameException$class_object;

#endif	/* _JC_java_nio_charset_IllegalCharsetNameException_H_ */
